Matomo Java Tracker Core 4.0.0 API
Packages
Package
Description
This package contains classes that allow you to specify a
MatomoTracker with the corresponding TrackerConfiguration.Contains types for Matomo Tracking Parameters according to the Matomo Tracking HTTP API.