All Classes and Interfaces

Class
Description
Describes the content for the Accept-Language header field that can be overridden by a custom parameter.
 
The type of action performed (download or outlink).
Wrapper for the cookie name and value.
A two-letter country code representing a country.
Deprecated.
Should not be used according to the Matomo FAQ: How do I use Custom Variables?
Deprecated.
Should not be used according to the Matomo FAQ: How do I use Custom Variables?
The resolution (width and height) of the user's output device (monitor / phone).
 
Represents an item in an ecommerce order.
 
Multiple things that you can buy online.
 
Helps to close an executor service.
Wraps a HttpServletRequest to be compatible with both the Jakarta and the Java EE API.
 
Thrown when an invalid URL is passed to the tracker.
Thrown when an error occurs while communicating with the Matomo server or when the request is invalid.
A class that implements the Matomo Tracking HTTP API.
 
This class contains static methods for common tracking items to create MatomoRequest objects.
The main class that sends MatomoRequests to a specified Matomo server.
A random value to avoid the tracking request being cached by the browser or a proxy.
A factory for Sender instances.
Defines configuration settings for the Matomo tracking.
 
A six character unique ID consisting of the characters [0-9a-Z].
The unique visitor ID, must be a 16 characters hexadecimal string.