JavaScript is disabled on your browser.
Skip navigation links
Overview
Package
Class
Use
Tree
Deprecated
Index
Help
SEARCH:
Deprecated API
Contents
Classes
Deprecated Classes
Class
Description
org.matomo.java.tracking.parameters.CustomVariable
Should not be used according to the Matomo FAQ:
How do I use Custom Variables?
org.matomo.java.tracking.parameters.CustomVariables
Should not be used according to the Matomo FAQ:
How do I use Custom Variables?