Package org.matomo.java.tracking
package org.matomo.java.tracking
This package contains classes that allow you to specify a
MatomoTracker with the corresponding TrackerConfiguration. You can then send a MatomoRequest as a single HTTP GET request or multiple requests as a
bulk HTTP POST request synchronously or asynchronously. If an exception occurs, MatomoException will be thrown.
For more information about the Matomo Tracking HTTP API, see the Matomo Tracking HTTP API.
-
ClassDescriptionThe type of action performed (download or outlink).Helps to close an executor service.Thrown when an invalid URL is passed to the tracker.Thrown when an error occurs while communicating with the Matomo server or when the request is invalid.A class that implements the Matomo Tracking HTTP API.This class contains static methods for common tracking items to create
MatomoRequestobjects.The main class that sendsMatomoRequests to a specified Matomo server.A factory forSenderinstances.Defines configuration settings for the Matomo tracking.